@@ -8,16 +8,17 @@ our @ISA = qw( Exporter );
 our @EXPORT_OK = qw( finger_client finger_server );
 
 # ABSTRACT: Simple asynchronous finger client and server
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
-sub finger_client
+sub finger_client ($$$;$)
 {
   my($hostname) = shift;
   require AnyEvent::Finger::Client;
   AnyEvent::Finger::Client
     ->new( hostname => $hostname )
     ->finger(@_);
+  ();
 }
 
 
@@ -27,14 +28,14 @@ sub finger_client
 # for ::Server instead.
 my $keep = [];
 
-sub finger_server
+sub finger_server ($;$)
 {
   require AnyEvent::Finger::Server;
   my $server = AnyEvent::Finger::Server
     ->new
     ->start(@_);
   push @$keep, $server;
-  return $server;
+  $server;
 }
 
 1;
@@ -51,7 +52,7 @@ AnyEvent::Finger - Simple asynchronous finger client and server
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -108,14 +109,18 @@ interface to client and server classes also in this distribution.
 
 =head1 FUNCTIONS
 
-=head2 finger_client( $server, $request, $callback, [ \%options ] )
+=head2 finger_client
+
+ finger_client( $server, $request, $callback, [ \%options ] )
 
 Send a finger request to the given server.  The callback will
 be called when the response is complete.  The options hash may
 be passed in as the optional forth argument to override any
 default options (See L<AnyEvent::Finger::Client> for details).
 
-=head2 finger_server( $callback, [ \%options ] )
+=head2 finger_server
+
+ my $server = finger_server $callback, \%options;
 
 Start listening to finger callbacks and call the given callback
 for each request.  See L<AnyEvent::Finger::Server> for details
@@ -141,10 +146,48 @@ for clients connecting via the loopback interface (localhost).
 
 =head1 SEE ALSO
 
+=over 4
+
+=item
+
 L<RFC1288|http://tools.ietf.org/html/rfc1288>,
+
+=item
+
 L<AnyEvent::Finger::Client>,
+
+=item
+
 L<AnyEvent::Finger::Server>
 
+=item
+
+L<AnyEvent>
+
+Generic non-blocking event loop used by L<AnyEvent::Finger>
+
+=item
+
+L<Net::Finger>
+
+Blocking implementation of a finger client
+
+=item
+
+L<Net::Finger::Server>
+
+Blocking implementation of a finger server
+
+=item
+
+L<PlugAuth::Plugin::Finger>
+
+PlugAuth plugin that allows querying a PlugAuth server
+via the finger protocol.  Uses this module for its
+implementation.
+
+=back
+
 =cut
 
 =head1 AUTHOR
