@@ -7,7 +7,7 @@ use AnyEvent::Handle;
 use Carp qw( carp );
 
 # ABSTRACT: Simple asynchronous finger client
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 sub new
@@ -91,7 +91,7 @@ AnyEvent::Finger::Client - Simple asynchronous finger client
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -118,6 +118,8 @@ Provide a simple asynchronous finger client.
 
 =head1 CONSTRUCTOR
 
+ my $client = AnyEvent::Finger::Client->new(%options);
+
 The constructor takes the following optional arguments:
 
 =over 4
@@ -151,7 +153,9 @@ Passes the error string as the first argument to the callback.
 
 =head1 METHODS
 
-=head2 $client-E<gt>finger($request, $callback, [ \%options ])
+=head2 finger
+
+ $client-E<gt>finger($request, $callback, [ \%options ])
 
 Connect to the finger server make the given request and call the given callback
 when the response is complete.  The response will be passed to the callback as
