@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Simple asynchronous finger response
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 sub say
@@ -32,7 +32,7 @@ AnyEvent::Finger::Response - Simple asynchronous finger response
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 DESCRIPTION
 
@@ -42,16 +42,40 @@ the documentation on that class for more details.
 
 =head1 METHODS
 
-=head2 $response-E<gt>say( @lines )
+=head2 say
+
+ $response->say( @lines )
 
 Send the lines to the client.  Do not include new line characters (\r, 
 \n or \r\n), these will be added by L<AnyEvent::Finger::Server>.
 
-=head2 $response-E<gt>done
+=head2 done
+
+ $response->done
 
 Close the connection with the client.  This signals that the response is
 complete.  Do not forget to call this!
 
+=head1 SEE ALSO
+
+=over 4
+
+=item
+
+L<AnyEvent::Finger>
+
+=item
+
+L<AnyEvent::Finger::Client>
+
+=item
+
+L<AnyEvent::Finger::Server>
+
+=back
+
+=cut
+
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
