@@ -11,7 +11,7 @@ use AnyEvent::Finger::Request;
 use AnyEvent::Finger::Response;
 
 # ABSTRACT: Simple asynchronous finger server
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 sub new
@@ -170,7 +170,7 @@ AnyEvent::Finger::Server - Simple asynchronous finger server
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -213,6 +213,10 @@ Provide a simple asynchronous finger server.
 
 =head1 CONSTRUCTOR
 
+=head2 new
+
+ my $server = AnyEvent::Finger::Server->new(%args);
+
 The constructor takes the following optional arguments:
 
 =over 4
@@ -266,7 +270,9 @@ on to the callback, like all other requests.
 
 =head1 METHODS
 
-=head2 $server-E<gt>start( $callback )
+=head2 start
+
+ $server->start( $callback )
 
 Start the finger server.  The callback will be called each time a
 client connects.
@@ -304,7 +310,9 @@ The server will unbind from its port and stop if the server
 object falls out of scope, or if the C<stop> method (see below)
 is called.
 
-=head2 $server-E<gt>bindport
+=head2 bindport
+
+ $server->bindport
 
 The bind port.  If port is set to zero in the constructor or on
 start, then an ephemeral port will be used, and you can get the
@@ -313,10 +321,28 @@ has been allocated and bound to a port, so if you need this
 value after calling C<start> but before any clients have connected
 use the C<on_bind> callback.
 
-=head2 $server-E<gt>stop
+=head2 stop
+
+ $server->stop
 
 Stop the server and unbind to the port.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item
+
+L<AnyEvent::Finger>
+
+=item
+
+L<AnyEvent::Finger::Client>
+
+=back
+
+=cut
+
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
