@@ -5,7 +5,7 @@ use warnings;
 use overload '""' => sub { shift->as_string };
 
 # ABSTRACT: Simple asynchronous finger transaction
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 sub res { shift->{res} }
@@ -32,7 +32,7 @@ AnyEvent::Finger::Transaction - Simple asynchronous finger transaction
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 DESCRIPTION
 
@@ -44,28 +44,60 @@ the remote client's address).
 
 =head1 ATTRIBUTES
 
-=head2 $tx-E<gt>req
+All attributes for this class are read-only.
+
+=head2 req
+
+ my $request = $tx->req;
 
 Returns the request object associated with the transaction
 (an instance of L<AnyEvent::Finger::Request>).
 
-=head2 $tx-E<gt>res
+=head2 res
+
+ my $response = $tx->res;
 
 Returns the response object associated with the transaction
 (an instance of L<AnyEvent::Finger::Response>).
 
-=head2 $tx-E<gt>remote_port
+=head2 remote_port
+
+ my $port = $tx->remote_port;
 
 Returns the remote TCP port being used to make the request.
 
-=head2 $tx-E<gt>local_port
+=head2 local_port
+
+ my $port = $tx->local_port;
 
 Returns the local TCP port being used to make the request.
 
-=head2 $tx-E<gt>remote_address
+=head2 remote_address
+
+ my $address = $tx-E<gt>remote_address;
 
 Returns the IP address from whence the finger request is coming from.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item
+
+L<AnyEvent::Finger>
+
+=item
+
+L<AnyEvent::Finger::Client>
+
+=item
+
+L<AnyEvent::Finger::Server>
+
+=back
+
+=cut
+
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
